/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.datamodel
 * File:    SearchResultReferenceImpl.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.datamodel;

import java.util.LinkedList;
import java.util.List;

import de.fhhannover.inform.iron.mapserver.datamodel.graph.Identifier;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.Link;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.MetadataContainer;
import de.fhhannover.inform.iron.mapserver.datamodel.graph.meta.Metadata;

/**
 * SearchResult implementation which does not copy the added containers and
 * metadata objects.
 * As a result, a {@link SearchResult} created with this implementation will
 * contain references to objects in the real graph. Be aware!
 * 
 * @version 0.1
 * @author aw, vp
 */

/*
 * created: 03.05.10
 * 
 * changes:
 *  03.05.10 aw, vp - ...
 *  08.06.10 aw - changed class visibility to package...
 *  11.06.10 aw - renamed from SearchResultImplReferences to
 *  SearchResultReferenceImpl
 * 
 */
class SearchResultReferenceImpl extends SearchResultImpl {

	public SearchResultReferenceImpl(String sessionId) {
		super(sessionId);
	}
	
	/* (non-Javadoc)
	 * @see de.fhhannover.inform.iron.mapserver.messages.SearchResult#addMetadata(de.fhhannover.inform.iron.mapserver.datamodel.graph.MetadataContainer, de.fhhannover.inform.iron.mapserver.datamodel.graph.meta.Metadata)
	 */
	public void addMetadata(MetadataContainer mc, Metadata m) {
		if (mc == null)
			return;
		
		List<Metadata> mcMetadata = null;
		if (mc instanceof Identifier) {
			Identifier ident = (Identifier)mc;
			int index = identifiers.indexOf(ident);
			if (index >= 0) {
				mcMetadata = iMetadata.get(index);
			} else {									// identifier not in list
				identifiers.add(ident);
				mcMetadata = new LinkedList<Metadata>();
				iMetadata.add(mcMetadata);
				index = identifiers.indexOf(ident);
			}
			
		} else if (mc instanceof Link) {
			Link link = (Link)mc;
			int index = links.indexOf(link);
			if (index >= 0) {
				mcMetadata = lMetadata.get(index);
			} else {									// link not in list
				links.add(link);
				mcMetadata = new LinkedList<Metadata>();
				lMetadata.add(mcMetadata);
			}
		}
		if (m != null) {
			mcMetadata.add(m);
		}
	}
}

