/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.messages.result
 * File:    NewSessionResult.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.messages.result;

import de.fhhannover.inform.iron.mapserver.communication.ChannelIdentifier;
import de.fhhannover.inform.iron.mapserver.messages.NewSessionRequest;
import de.fhhannover.inform.iron.mapserver.utils.NullCheck;

/**
 * 
 * 
 * @author aw
 *
 */
public class NewSessionResult extends Result {
	
	private final String mSessionId;
	private final String mPublisherId;
	private final long mMaxPollResultSize;
	
	
	public NewSessionResult(ChannelIdentifier channelId, String sessionId,
			String publisherId, long maxPollResultSize) {
		super(channelId);
		
		NullCheck.check(sessionId, "session-id not set");
		NullCheck.check(publisherId, "publisher-id not set");
		
		if ((maxPollResultSize != NewSessionRequest.MAX_POLL_RESULT_NOT_GIVEN)
			&& !(maxPollResultSize >= 0)) {
				throw new ResultConstructionException("max-poll-result-size wrong: " +
						maxPollResultSize);
			
		}
		
		if (sessionId.length() == 0) {
			throw new ResultConstructionException("session-id length=0");
		}
		
		if (publisherId.length() == 0) {
			throw new ResultConstructionException("publisher-id length=0");
		}
		mSessionId = sessionId;
		mPublisherId = publisherId;
		mMaxPollResultSize = maxPollResultSize;
	}
	
	public String getSessionId() {
		return mSessionId;
	}

	public String getPublisherId() {
		return mPublisherId;
	}

	public long getMaxPollResultSize() {
		return mMaxPollResultSize;
	}
}
