/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.mapserver.messages.result
 * File:    PollResult.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.mapserver.messages.result;

import de.fhhannover.inform.iron.mapserver.communication.ChannelIdentifier;
import de.fhhannover.inform.iron.mapserver.messages.NewSessionRequest;
import de.fhhannover.inform.iron.mapserver.utils.NullCheck;

/**
 * This is as stupid as {@link SearchResult}, we encapsulate a datamodel
 * pollResult in one that just indicates a pollResult has to be send out.
 * 
 * @author aw
 *
 */
public class PollResult extends Result {
	
	private final de.fhhannover.inform.iron.mapserver.messages.PollResult mPollResult;
	private final long mMaxPollResultSize;

	public PollResult(ChannelIdentifier channelId,
			de.fhhannover.inform.iron.mapserver.messages.PollResult pollResult,
			long maxPollResultSize) {
		super(channelId);
		
		NullCheck.check(pollResult, "pollResult is null");
		mPollResult = pollResult;
		
		if ((maxPollResultSize != NewSessionRequest.MAX_POLL_RESULT_NOT_GIVEN)
				&& !(maxPollResultSize >= 0)) {
				throw new ResultConstructionException("max-poll-result-size wrong: " +
						maxPollResultSize);
				
			}
		mMaxPollResultSize = maxPollResultSize;
	}

	public de.fhhannover.inform.iron.mapserver.messages.PollResult getPollResult() {
		return mPollResult;
	}

	public long getMaxPollResultSize() {
		return mMaxPollResultSize;
	}
}
